==> jc-1.4.0.tar.gz: soot/util/SmallNumberedMap__24KeyIterator.h <==
// class soot.util.SmallNumberedMap$KeyIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ccfc73d973f3ea75 soot_util_SmallNumberedMap__24KeyIterator
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator

// header file dependencies
// @dep_header soot_util_SmallNumberedMap__24SmallNumberedMapIterator

#include "soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h"

#ifndef _JC_soot_util_SmallNumberedMap__24KeyIterator_H_
#define _JC_soot_util_SmallNumberedMap__24KeyIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$refs	_jc_soot_util_SmallNumberedMap__24KeyIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object	_jc_soot_util_SmallNumberedMap__24KeyIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods	_jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtable	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24KeyIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24KeyIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24KeyIterator$method_info$next$05874f79a1cf66ea;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *);
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods	soot_util_SmallNumberedMap__24KeyIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$refs {
    _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs	soot_util_SmallNumberedMap__24KeyIterator;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs	soot_util_SmallNumberedMap__24KeyIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object {
	_jc_soot_util_SmallNumberedMap__24KeyIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype _jc_soot_util_SmallNumberedMap__24KeyIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24KeyIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24KeyIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24KeyIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/SmallNumberedMap__24KeyIterator.h <==
// class soot.util.SmallNumberedMap$KeyIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ccfc73d973f3ea75 soot_util_SmallNumberedMap__24KeyIterator
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator

// header file dependencies
// @dep_header soot_util_SmallNumberedMap__24SmallNumberedMapIterator

#include "soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h"

#ifndef _JC_soot_util_SmallNumberedMap__24KeyIterator_H_
#define _JC_soot_util_SmallNumberedMap__24KeyIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$refs	_jc_soot_util_SmallNumberedMap__24KeyIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object	_jc_soot_util_SmallNumberedMap__24KeyIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods	_jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtable	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24KeyIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24KeyIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24KeyIterator$method_info$next$05874f79a1cf66ea;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vmethods	soot_util_SmallNumberedMap__24KeyIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$refs {
    _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_refs	soot_util_SmallNumberedMap__24KeyIterator;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_soot_util_SmallNumberedMap__24KeyIterator$sub_nonrefs	soot_util_SmallNumberedMap__24KeyIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24KeyIterator$object {
	_jc_soot_util_SmallNumberedMap__24KeyIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24KeyIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24KeyIterator$vtype _jc_soot_util_SmallNumberedMap__24KeyIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24KeyIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24KeyIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24KeyIterator_H_ */
